<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation>Cortar (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation>Copiar (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation>Pegar (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation>Deshacer (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation>Rehacer (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation>Potencia (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation>Paréntesis (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation>Valor absoluto (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation>Fracción (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation>Raíz (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation>Distancia {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation>Circunferencia {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation>Longitud {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation>Radio {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation>Arco de ángulo {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation>Ángulo {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation>Razón {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation>Pendiente {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation>Área {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation>el punto</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>el segmento</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation>el rayo</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>la recta</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>el círculo</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>el arco</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>el polígono</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation>el interior del círculo</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation>el sector de arco</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation>el segmento de arco</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation>el lugar geométrico</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation>la medida</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>el cálculo</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>la anotación</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation>Indefinido</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation>El valor está indefinido</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation>El valor es %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation>Inserte %1 %2</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation>Ciclar sobre %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation>o</translation>
    </message>
    <message>
        <source>final</source>
        <translation>final</translation>
    </message>
    <message>
        <source>initial</source>
        <translation>inicial</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation>no construido</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation>no existe</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation>oculto</translation>
    </message>
    <message>
        <source>Given</source>
        <translation>Dado</translation>
    </message>
    <message>
        <source>Final</source>
        <translation>Final</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation>Inicial</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 es la traslación de %2 por el vector de %3 a %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation>%1 es la rotación de %2 por %4 grados alrededor de %3</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation>%1 es la imagen de %2 rescalada por la razón %4:%5 con respecto a %3</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation>%1 es la imagen de %2 rescalada por factor %4 con respecto a %3</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation>%1 es la reflexión de %2 con respecto a %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation>%1 es libre</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation>%1 está en %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation>%1 es la intersección de %2 y %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation>%1 es la 2a intersección de %2 y %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation>%1 es el punto medio de %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 tiene extremos %2 y %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation>%1 va de %2 a %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation>%1 bisecta el ángulo %2 %3 %4</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation>%1 está entre %2 y %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation>%1 es paralela a %2 pasando por %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation>%1 es perpendicular a %2 pasando por %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation>%1 tiene centro en %2 y pasa por %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation>%1 tiene centro en %2 y radio %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation>%1 pasa por los puntos %2, %3 y %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation>%1 es trazado por %2, guiado por %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 involucra %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation>%1 es la distancia entre %2 y %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation>%1 es la longitud de %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation>%1 es el ángulo de %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation>%1 es el ángulo entre los puntos %1, %2 y %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation>%1 es la razón de %2 a %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation>%1 es la pendiente de %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation>%1 es el área de %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation>%1 es definido por %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation>%1 tiene vértices en los puntos %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation>%1 es el radio de %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation>%1 es el extremo de %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation>%1 es el segundo extremo de %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation>%1 es el centro de %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation>Preferencias de KSEG</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation>Color de fondo</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation>Color de primer plano por defecto</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation>Mostrar la selección</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation>Selección de borde</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation>Selección parpadeante</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation>Entre la profundidad de recursión:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation>Producirá demasiados objetos.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation>Producirá %1 objetos.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation>Ejemplos de lugar geométrico:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation>Deseleccionar</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation>Nuevo groupo</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation>Eliminar el grupo</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation>Afectar 
objetos
invisibles </translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation>Mantenga oprimido SHIFT y haga clic para añadir a la selección actual</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation>Si los grupos &quot;Todo &lt;Tipo&gt;&quot; también (de)seleccionan los objetos invisibles</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation>Todos los puntos</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation>Todos los segmentos</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation>Todos los rayos</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation>Todas las rectas</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation>Todos los círculos</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation>Todos los arcos</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation>Todos los polígonos</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation>Todos los interiores de círculos</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation>Todos los sectores de arco</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation>Todos los segmentos de arco</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation>Todos los lugares geométricos</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation>Todas las medidas</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation>Todos los cálculos</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Entre un nuevo nombre de grupo:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation>¿Está seguro de querer eliminar el (los) group(s) seleccionado(s)?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Listo</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation>Mover la etiqueta de %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation>Seleccionar %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation>Deseleccionar %1 %2</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation>También seleccionar %1 %2</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation>Mover los objetos seleccionados</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation>Reconstreñir %1 %2 para que sea libre</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation>Reconstreír %1 %2 a %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation>Reconstreñir %1 %2 a la intersección de %3 %4 y %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation>Vista panorámica</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Acercamiento</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation>kseg: Sin título</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation>Me&amp;dir</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation>&amp;Transformar</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation>Ani&amp;mar</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation>Const&amp;rucción</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation>&amp;Nuevo croquis</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation>Nue&amp;va construcción</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation>Nueva Vis&amp;ta</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>A&amp;brir...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>G&amp;uardar como...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimir...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation>Elegir el &amp;lenguage...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Re&amp;hacer</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation>Elimina&amp;r objetos</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation>Mostrar/ocultar e&amp;tiqueta</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation>Ocultar Etiqueta</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation>Mostrar etiqueta</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation>Cambiar eti&amp;queta...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation>Ocultar Ob&amp;jetos</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation>Desoc&amp;ultar todos</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Color</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation>E&amp;stilo de línea</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation>Estilo de &amp;punto</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Fuente</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation>Cambiar &amp;número de muestras...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation>&amp;Otro...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation>&amp;Fuente...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation>Punto de &amp;intersección</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation>&amp;Segmento</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation>Punto &amp;Medio</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation>Ra&amp;yo</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation>&amp;Recta</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation>Recta &amp;perpendicular</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation>&amp;Círculo por centro y punto</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation>Arco por &amp;tres puntos</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation>&amp;Bisectriz de ángulo</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation>Lugar &amp;geométrico</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation>P&amp;olígono</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation>S&amp;ector de arco</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation>Segmen&amp;to de arco</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation>I&amp;nterior de círculo</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation>&amp;Distancia</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation>&amp;Longitud</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation>&amp;Radio</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation>&amp;Angulo</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation>Ra&amp;zón</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation>&amp;Pendiente</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation>Ár&amp;ea</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation>&amp;Calcular...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation>Elegir el &amp;vector</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation>Elegir el eje de refle&amp;xión</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation>Elegir el &amp;centro</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation>Elegir el á&amp;ngulo</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation>Elegir la ra&amp;zón</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation>&amp;Borrar los elegidos</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation>&amp;Traslación</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation>R&amp;eflexión</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation>&amp;Homotecia</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotación</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation>Convertir en &amp;normal</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation>Convertir en &amp;dado</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation>Convertir en &amp;final</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation>Convertir en &amp;inicial</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation>Iterar &amp;recursivamente</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation>An&amp;imación rápida</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Acerca de...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation>&amp;Circunferencia</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation>&amp;Longitud de arco</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation>Mostrar/ocultar eti&amp;quetas</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation>Ocultar etiquetas</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation>Mostrar etiquetas</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation>&amp;Segmentos</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation>&amp;Rayos</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation>Puntos &amp;medios</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation>Puntos de &amp;intersection</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation>&amp;Círculo por centro y radio</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation>&amp;Rectas</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation>&amp;Lines paralelas</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation>&amp;Recta paralela</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation>Rectas &amp;perpendiculares</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation>&amp;Cambiar directorio...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation>No hay Construcciones</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation>Guardar?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation>Le gustaría guardar los cambios?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Archivo no encontrado</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation>El archivo %1 not existe.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Archivo inválido</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation>El archivo %1 no parece ser un archivo válido de KSEG.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation>Cambio de lenguage</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation>Necesitará reiniciar KSEG para que el cambio de lenguage sea efectivo.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation>Acerca de KSEG</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation>&amp;Eliminar Objeto</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation>Oc&amp;ultar objeto</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation>Prefe&amp;rencias...</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation>Abrir en la ventana actual...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation>Copiar como construcción</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation>&amp;Grupos de selección...</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation>KSEG v%1
Derechos reservados por Ilya Baran (%2).
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>A&amp;cercamiento</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation>Vista &amp;panorámica</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation>Acercamiento a&amp;justado</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation>Acercamiento &amp;original (100%)</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation>E&amp;xportar a imagen...</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation>Extremos</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation>Punto central</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation>Extremo</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation>Acercamiento:</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation>Elija el formato de archivo:</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation>Imagen de alta calidad</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation>Exportando.  Espere por favor...</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation>Filas:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Columnas:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation>Llenar de zeros</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
</TS>
